@@ -1,6 +1,6 @@
-# $Id: install.py 964 2014-07-22 02:35:10Z mwall $
+# $Id: install.py 1729 2017-09-04 10:53:23Z mwall $
 # installer for exfoliation
-# Copyright 2014 Matthew Wall
+# Copyright 2014-2017 Matthew Wall
 
 from setup import ExtensionInstaller
 
@@ -10,7 +10,7 @@ def loader():
 class ExfoliationInstaller(ExtensionInstaller):
     def __init__(self):
         super(ExfoliationInstaller, self).__init__(
-            version="0.29",
+            version="0.41",
             name='exfoliation',
             description='A minimalist layout with lots of data.',
             author="Matthew Wall",
@@ -19,18 +19,21 @@ class ExfoliationInstaller(ExtensionInstaller):
                 'StdReport': {
                     'exfoliation': {
                         'skin':'exfoliation',
-                        'HTML_ROOT':'exfoliation',
-                        'Extras': {
-                            'footer':'INST_SKIN_ROOT/exfoliation/footer.inc',
-                            'header':'INST_SKIN_ROOT/exfoliation/header.inc',
-                            'hilo':'INST_SKIN_ROOT/exfoliation/hilo.inc'}}}},
+                        'HTML_ROOT':'exfoliation'}}},
             files=[('skins/exfoliation',
                     ['skins/exfoliation/almanac.html.tmpl',
+                     'skins/exfoliation/cookies.js',
                      'skins/exfoliation/exfoliation.css',
                      'skins/exfoliation/exfoliation.js',
                      'skins/exfoliation/favicon.ico',
                      'skins/exfoliation/footer.inc',
                      'skins/exfoliation/forecast.html.tmpl',
+                     'skins/exfoliation/forecast_iconic.css',
+                     'skins/exfoliation/forecast_iconic.inc',
+                     'skins/exfoliation/forecast_strip.css',
+                     'skins/exfoliation/forecast_strip.inc',
+                     'skins/exfoliation/forecast_table.css',
+                     'skins/exfoliation/forecast_table.inc',
                      'skins/exfoliation/header.inc',
                      'skins/exfoliation/hilo.inc',
                      'skins/exfoliation/history.html.tmpl',
@@ -42,6 +45,13 @@ class ExfoliationInstaller(ExtensionInstaller):
                    ('skins/exfoliation/NOAA',
                     ['skins/exfoliation/NOAA/NOAA-YYYY-MM.txt.tmpl',
                      'skins/exfoliation/NOAA/NOAA-YYYY.txt.tmpl']),
+                   ('skins/exfoliation/font',
+                    ['skins/exfoliation/font/Roboto-Bold.ttf',
+                     'skins/exfoliation/font/Roboto-Bold.woff',
+                     'skins/exfoliation/font/Roboto-Bold.woff2',
+                     'skins/exfoliation/font/Roboto-Regular.ttf',
+                     'skins/exfoliation/font/Roboto-Regular.woff',
+                     'skins/exfoliation/font/Roboto-Regular.woff2']),
                    ('skins/exfoliation/icons',
                     ['skins/exfoliation/icons/AF.png',
                      'skins/exfoliation/icons/B1.png',
@@ -82,7 +92,9 @@ class ExfoliationInstaller(ExtensionInstaller):
                      'skins/exfoliation/icons/frzngdrzl.png',
                      'skins/exfoliation/icons/moon.png',
                      'skins/exfoliation/icons/moonphase.png',
+                     'skins/exfoliation/icons/moonrise.png',
                      'skins/exfoliation/icons/moonriseset.png',
+                     'skins/exfoliation/icons/moonset.png',
                      'skins/exfoliation/icons/pop.png',
                      'skins/exfoliation/icons/rain.png',
                      'skins/exfoliation/icons/raindrop.png',
@@ -95,7 +107,25 @@ class ExfoliationInstaller(ExtensionInstaller):
                      'skins/exfoliation/icons/sprinkles.png',
                      'skins/exfoliation/icons/sun.png',
                      'skins/exfoliation/icons/sunmoon.png',
+                     'skins/exfoliation/icons/sunrise.png',
                      'skins/exfoliation/icons/sunriseset.png',
+                     'skins/exfoliation/icons/sunset.png',
+                     'skins/exfoliation/icons/tE.png',
+                     'skins/exfoliation/icons/tENE.png',
+                     'skins/exfoliation/icons/tESE.png',
+                     'skins/exfoliation/icons/tN.png',
+                     'skins/exfoliation/icons/tNE.png',
+                     'skins/exfoliation/icons/tNNE.png',
+                     'skins/exfoliation/icons/tNNW.png',
+                     'skins/exfoliation/icons/tNW.png',
+                     'skins/exfoliation/icons/tS.png',
+                     'skins/exfoliation/icons/tSE.png',
+                     'skins/exfoliation/icons/tSSE.png',
+                     'skins/exfoliation/icons/tSSW.png',
+                     'skins/exfoliation/icons/tSW.png',
+                     'skins/exfoliation/icons/tW.png',
+                     'skins/exfoliation/icons/tWNW.png',
+                     'skins/exfoliation/icons/tWSW.png',
                      'skins/exfoliation/icons/thermometer-blue.png',
                      'skins/exfoliation/icons/thermometer-dewpoint.png',
                      'skins/exfoliation/icons/thermometer-red.png',
